﻿/*******************************************************************************
File        : Program.cs
Description : 
--------------------------------------------------------------------------------
Functions:
--------------------------------------------------------------------------------
History:
2011/05/16 TPR Created
*******************************************************************************/
using System;
using Wiker.WIDatabase;
using System.Collections.ObjectModel;
using System.Text;


namespace MultipleJoin
{
   /*******************************************************************************
   Class        : Program
   Description  : 
   --------------------------------------------------------------------------------
   History:
   2011/05/16 TPR Created
   *******************************************************************************/
   class Program
   {      
      /*******************************************************************************
      Function    : Main()
      Description : 
      Parameters  : string[] args - 
      Returns     : void
      --------------------------------------------------------------------------------
      History:
      2011/05/16 TPR Created
      *******************************************************************************/
      static void Main(string[] args)
      {
         WIDatabase WIDB;
         string ColumnDataStr;
         StringBuilder StrB;
         CDatabaseInfo DBInfo;

         /* Create DatabaseInfo object with login info  */
         DBInfo = new CDatabaseInfo();
         DBInfo.DatabaseType = eDatabaseType.SQLite;
         DBInfo.Location =  "\\WIDatabase\\Samples";
         DBInfo.DBName = "SQLite.db3";         
         DBInfo.Password = "";
         DBInfo.Port = 0;
         DBInfo.Username = "";

         /* Create WIDatabase object */
         WIDB = new WIDatabase(DBInfo);
         
         /* Calling Select.Clear() ensures we starting with a new select statement. */
         WIDB.Search.Clear();

         /* The Column Class is used to choose columns to be returned */
         WIDB.Search.Column("tblPerson","Name","PersonName");
         WIDB.Search.Column("tblCompany","Name","CompanyName");
         WIDB.Search.Column("tblAddress", "Address1","PersonAddress1");
         WIDB.Search.Column("tblAddress","Address2","PersonAddress2");
         WIDB.Search.Column("tblAddress","City","PersonCity");
         WIDB.Search.Column("tblAddress","State","PersonState");
         WIDB.Search.Column("tblAddress","ZipCode","PersonZipCode");

         /* Select.Table: The 'Main' table from which the data will originate */
         WIDB.Search.Table("tblPerson");

         /* Select.Join: Used to 'connect' related tables. */
         WIDB.Search.Join("tblCompany","CompanyID", eOperator.Equal,"tblPerson","CompanyID", eJoinType.Normal);
         WIDB.Search.Join("tblAddress","AddressID", eOperator.Equal,"tblPerson","AddressID", eJoinType.Normal);

         /* Select.Execute() prepares the statement to be sent to the Database */
         WIDB.Search.Execute();

         Console.WriteLine("| PersonName | CompanyName | PersonAddress1 | PersonAddress2 | PersonCity | PersonState | PersonZipCode |");

         /* Select.Read() reads the next row from the returned data */
         while (WIDB.Search.Read())
            {
            StrB = new StringBuilder();

            /* Select.Get obtains the value of the named column via an out parameter */
            WIDB.Search.Get("PersonName",out ColumnDataStr);
            StrB.AppendFormat("| {0} ",ColumnDataStr);

            WIDB.Search.Get("CompanyName",out ColumnDataStr);
            StrB.AppendFormat("| {0} ",ColumnDataStr);

            WIDB.Search.Get("PersonAddress1",out ColumnDataStr);
            StrB.AppendFormat("| {0} ",ColumnDataStr);

            WIDB.Search.Get("PersonAddress2",out ColumnDataStr);
            StrB.AppendFormat("| {0} ",ColumnDataStr);

            WIDB.Search.Get("PersonCity",out ColumnDataStr);
            StrB.AppendFormat("| {0} ",ColumnDataStr);

            WIDB.Search.Get("PersonState",out ColumnDataStr);
            StrB.AppendFormat("| {0} ",ColumnDataStr);

            WIDB.Search.Get("PersonZipCode",out ColumnDataStr);
            StrB.AppendFormat("| {0} ",ColumnDataStr);

            Console.WriteLine(StrB.ToString());
            }

         /* Good practice is to close the DB when finished */
         WIDB.Close();
      }
   }/* End Class */
}/* End NameSpace */
